#
# spec file for package docbook-simple
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           docbook-simple
BuildRequires:  unzip
Summary:        Simple DocBook DTD and Documentation
License:        HPND
Group:          Productivity/Publishing/DocBook
Version:        1.1
Release:        1.6
BuildArch:      noarch
Requires:       libxml2-tools
Requires:       sgml-skel
Requires(post): /usr/bin/install-catalog
Requires(post): /usr/bin/xmlcatalog
Requires(postun): /usr/bin/xmlcatalog
URL:            https://www.oasis-open.org/docbook/xml/simple/
Source0:        https://www.oasis-open.org/docbook/xml/simple/%{version}/docbook-simple-%{version}.zip
Source1:        %{name}-%{version}.cat
Source2:        %{name}-%{version}.xml

%description
This package contains the Simple DocBook DTD.

%define xml_dir %{_datadir}/xml
%define sgml_dir %{_datadir}/sgml
%define xml_mod_root %{xml_dir}/docbook/simple
%define xml_mod_dir %{xml_mod_root}/%{version}
%define sgml_sysconf_dir %{_sysconfdir}/sgml
%define xml_sysconf_dir %{_sysconfdir}/xml
%define xml_catalog %{xml_sysconf_dir}/catalog
%define sgml_catalog %{sgml_sysconf_dir}/catalog

%prep
%setup -q -c -n %{version}
sed 's|@XML_DTD_DIR@|%{xml_mod_dir}|' %{SOURCE1} > $(basename %{SOURCE1})
sed 's|@XML_DTD_DIR@|%{xml_mod_dir}|' %{SOURCE2} > $(basename %{SOURCE2})
# make sure everything is readable
chmod a+r *

%build
# nothing to build

%install
# install versioned directory of dtd files
mkdir -p %{buildroot}%{xml_mod_dir}
cp -a *.{css,dtd,mod} %{buildroot}%{xml_mod_dir}
# install package catalogs
mkdir -p %{buildroot}%{sgml_dir}
mkdir -p %{buildroot}%{xml_mod_dir}
install -p -m 644 "$(basename %{SOURCE1})" %{buildroot}%{sgml_dir}
install -p -m 644 "$(basename %{SOURCE2})" %{buildroot}%{xml_mod_root}

%post
# SGML catalog registration
if [ -w %{sgml_catalog} ]; then
  install-catalog --add \
    "%{sgml_dir}/%{name}-%{version}.cat" \
    "%{sgml_catalog}" 1>/dev/null
# Workaround bug in install-catalog (from Fedora)
  sed -i '/^CATALOG.*log\"$/d' %{sgml_dir}/%{name}-%{version}.cat
  sed -i '/^CATALOG.*log$/d' %{sgml_dir}/%{name}-%{version}.cat
fi
# XML catalog registration
if [ -w %{xml_catalog} ]; then
  xmlcatalog --noout --add "delegatePublic" \
    "-//OASIS//DTD Simplified" \
    "file://%{xml_mod_dir}/%{name}-%{version}.xml" %{xml_catalog}
  xmlcatalog --noout --add "delegateURI" \
    "http://www.oasis-open.org/docbook/xml/simple/1.1/" \
    "file://%{xml_mod_dir}/%{name}-%{version}.xml" %{xml_catalog}
# Some resolvers misinterpret uri entries
  xmlcatalog --noout --add "delegateSystem" \
    "http://www.oasis-open.org/docbook/xml/simple/1.1/" \
    "file://%{xml_mod_dir}/%{name}-%{version}.xml" %{xml_catalog}
fi

%postun
if [ "$1" = 0 ]; then
  xmlcatalog --sgml --noout --del \
    %{sgml_catalog} \
    %{sgml_dir}/%{name}-%{version}.cat

  xmlcatalog --noout --del \
    "file://%{xml_mod_dir}/%{name}-%{version}.xml" \
     %{xml_catalog} 
fi
 
%files
%{xml_mod_dir}
%dir %{xml_mod_root}
%{sgml_dir}/%{name}-%{version}.cat
%{xml_mod_root}/%{name}-%{version}.xml

%changelog
* Tue Jun  8 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to docbook-simple version 1.1
  * customization of xml/4.3
* Thu Mar  7 2013 cfarrell@suse.com
- license update: HPND
  License more akin to HPND
* Sat Mar  2 2013 coolo@suse.com
- update license to new format
* Sat Feb 25 2012 meissner@suse.de
- libxml2 tools are now in libxml2-tools
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
  (cf. packaging guidelines)
* Thu Dec 24 2009 aj@suse.de
- Only remove file from catalog if it disappeared.
- Do not use release numbers, they're not needed anymore.
* Thu Mar 29 2007 aj@suse.de
- Add unzip as BuildRequires.
* Fri Jan 12 2007 ke@suse.de
- Remove /usr/share/xml from the files list.
* Tue Aug 15 2006 ke@suse.de
- Remove SuSEconfig calls.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Feb 13 2004 ke@suse.de
- Adjust directories according to FHS 2.3:
  * Move files to /usr/share/xml/docbook/custom/simple.
  * Provide compatibility links for SL =< 9.0 (log this info in
    /var/adm/SuSEconfig/run-sgmldir-links for later processing).
* Wed Feb  4 2004 hmacht@suse.de
- added option # norootforbuild in specfile
* Tue Jun 10 2003 coolo@suse.de
- fix syntax error
* Thu Jun  5 2003 ke@suse.de
- Create absolute links.
- Fix file list.
* Fri May 23 2003 ke@suse.de
- New package: version 1.0 (prepared by Thomas Schraitle).
